Class: MicroformatScraper::EventParser
- Inherits:
-
Object
- Object
- MicroformatScraper::EventParser
- Defined in:
- lib/microformat_scraper/event_parser.rb
Instance Method Summary collapse
-
#parse(content) ⇒ Object
This method is extremely fragile, but so far EOLclub.org has been sticking to the same format, so that may be okay.
Instance Method Details
#parse(content) ⇒ Object
This method is extremely fragile, but so far EOLclub.org has been sticking to the same format, so that may be okay.
10 11 12 13 |
# File 'lib/microformat_scraper/event_parser.rb', line 10 def parse(content) doc = Nokogiri::HTML.parse(content) doc.css('.vevent').map{|elem| parse_event(elem)} end |